CommandRunner

Struct CommandRunner 

pub struct CommandRunner {
    pub working_dir: Option<PathBuf>,
    pub env: Vec<(String, String)>,
    pub inherit_env: bool,
}
A command runner that captures output and provides structured results.

Fields

working_dir: Option<PathBuf>

Working directory for commands

env: Vec<(String, String)>

Environment variables to set

inherit_env: bool

Whether to inherit the parent environment

Implementations

Source

impl CommandRunner

pub fn new() -> Self

Create a new command runner.

pub fn with_working_dir(self, dir: impl AsRef<Path>) -> Self

Set the working directory.

pub fn with_env(self, key: impl Into<String>, value: impl Into<String>) -> Self

Add an environment variable.

pub fn with_ghc_bin(self, bin_dir: impl AsRef<Path>) -> Self

Configure PATH to use a specific toolchain bin directory.

Prepends the given bin directory to PATH, ensuring tools from that directory are found first. Can be called multiple times to add multiple bin directories.

pub async fn run<S, I>( &self, program: S, args: I, ) -> Result<CommandOutput, Error>
where S: AsRef<OsStr>, I: IntoIterator<Item = S>,

Run a command and capture output.

pub async fn run_checked<S, I>( &self, program: S, args: I, ) -> Result<CommandOutput, Error>
where S: AsRef<OsStr>, I: IntoIterator<Item = S>,

Run a command and return an error if it fails.