Error

Enum Error 

pub enum Error {
    ToolchainMissing {
        tool: String,
        source: Option<Box<dyn Error + Send + Sync>>,
        fixes: Vec<Fix>,
    },
    ToolchainMismatch {
        tool: String,
        expected: String,
        found: String,
        fixes: Vec<Fix>,
    },
    Config {
        message: String,
        path: Option<PathBuf>,
        source: Option<Box<dyn Error + Send + Sync>>,
        fixes: Vec<Fix>,
    },
    Io {
        message: String,
        path: Option<PathBuf>,
        source: Error,
    },
    CommandFailed {
        command: String,
        exit_code: Option<i32>,
        stdout: String,
        stderr: String,
        fixes: Vec<Fix>,
    },
    BuildFailed {
        errors: Vec<String>,
        fixes: Vec<Fix>,
    },
    Lock {
        message: String,
        source: Option<Box<dyn Error + Send + Sync>>,
        fixes: Vec<Fix>,
    },
    ProjectNotFound {
        searched: Vec<PathBuf>,
        fixes: Vec<Fix>,
    },
    Other(Error),
}
Structured error type for hx.

Variants



ToolchainMissing

Fields

tool: String
source: Option<Box<dyn Error + Send + Sync>>
fixes: Vec<Fix>


ToolchainMismatch

Fields

tool: String
expected: String
found: String
fixes: Vec<Fix>


Config

Fields

message: String
source: Option<Box<dyn Error + Send + Sync>>
fixes: Vec<Fix>


Io

Fields

message: String
source: Error


CommandFailed

Fields

command: String
exit_code: Option<i32>
stdout: String
stderr: String
fixes: Vec<Fix>


BuildFailed

Fields

errors: Vec<String>
fixes: Vec<Fix>


Lock

Fields

message: String
source: Option<Box<dyn Error + Send + Sync>>
fixes: Vec<Fix>


ProjectNotFound

Fields

searched: Vec<PathBuf>
fixes: Vec<Fix>


Other(Error)

Implementations

Source

impl Error

pub fn code(&self) -> ErrorCode

Get the error code for this error.

pub fn fixes(&self) -> &[Fix]

Get suggested fixes for this error.

pub fn config(message: impl Into<String>) -> Self

Create a config error.

pub fn config_at(message: impl Into<String>, path: impl Into<PathBuf>) -> Self

Create a config error with a path.

pub fn toolchain_missing(tool: impl Into<String>) -> Self

Create a toolchain missing error with default fix suggestions.

pub fn toolchain_mismatch( tool: impl Into<String>, expected: impl Into<String>, found: impl Into<String>, ) -> Self

Create a toolchain mismatch error with default fix suggestions.

pub fn project_not_found(searched: Vec<PathBuf>) -> Self

Create a project not found error with helpful suggestions.

pub fn lock_outdated() -> Self

Create a lock error with suggestions.

pub fn build_failed(errors: Vec<String>) -> Self

Create a build failed error with common suggestions.