pub struct CommandRunner {
pub working_dir: Option<PathBuf>,
pub env: Vec<(String, String)>,
pub inherit_env: bool,
}Expand description
A command runner that captures output and provides structured results.
Fields
working_dir: Option<PathBuf>Working directory for commands
env: Vec<(String, String)>Environment variables to set
inherit_env: boolWhether to inherit the parent environment
Implementations
Sourceimpl CommandRunner
impl CommandRunner
Sourcepub fn with_working_dir(self, dir: impl AsRef<Path>) -> Self
pub fn with_working_dir(self, dir: impl AsRef<Path>) -> Self
Set the working directory.
Sourcepub fn with_env(self, key: impl Into<String>, value: impl Into<String>) -> Self
pub fn with_env(self, key: impl Into<String>, value: impl Into<String>) -> Self
Add an environment variable.
Sourcepub fn with_ghc_bin(self, bin_dir: impl AsRef<Path>) -> Self
pub fn with_ghc_bin(self, bin_dir: impl AsRef<Path>) -> Self
Configure PATH to use a specific toolchain bin directory.
Prepends the given bin directory to PATH, ensuring tools from that directory are found first. Can be called multiple times to add multiple bin directories.
Sourcepub async fn run<S, I>(
&self,
program: S,
args: I,
) -> Result<CommandOutput, Error>
pub async fn run<S, I>( &self, program: S, args: I, ) -> Result<CommandOutput, Error>
Run a command and capture output.
Sourcepub async fn run_checked<S, I>(
&self,
program: S,
args: I,
) -> Result<CommandOutput, Error>
pub async fn run_checked<S, I>( &self, program: S, args: I, ) -> Result<CommandOutput, Error>
Run a command and return an error if it fails.